@@ -39,14 +39,13 @@ class Metrics(MetricManager):
         metrics.add_dimension(name="function_version", value="$LATEST")
         ...
 
-        @tracer.capture_lambda_handler
         @metrics.log_metrics()
         def lambda_handler():
-                do_something()
-                return True
+               do_something()
+               return True
 
         def do_something():
-                metrics.add_metric(name="Something", unit="Count", value=1)
+               metrics.add_metric(name="Something", unit="Count", value=1)
 
     Environment variables
     ---------------------
@@ -57,13 +56,19 @@ class Metrics(MetricManager):
 
     Parameters
     ----------
-    MetricManager : MetricManager
-        Inherits from `aws_lambda_powertools.metrics.base.MetricManager`
+    service : str, optional
+        service name to be used as metric dimension, by default "service_undefined"
+    namespace : str
+        Namespace for metrics
 
     Raises
     ------
-    e
-        Propagate error received
+    MetricUnitError
+        When metric metric isn't supported by CloudWatch
+    MetricValueError
+        When metric value isn't a number
+    SchemaValidationError
+        When metric object fails EMF schema validation
     """
 
     _metrics = {}
@@ -105,12 +110,14 @@ class Metrics(MetricManager):
         -------
         **Lambda function using tracer and metrics decorators**
 
+            from aws_lambda_powertools import Metrics, Tracer
+
             metrics = Metrics(service="payment")
             tracer = Tracer(service="payment")
 
             @tracer.capture_lambda_handler
             @metrics.log_metrics
-                def handler(event, context):
+            def handler(event, context):
                     ...
 
         Parameters
@@ -150,7 +157,7 @@ class Metrics(MetricManager):
                 else:
                     metrics = self.serialize_metric_set()
                     self.clear_metrics()
-                    print(json.dumps(metrics))
+                    print(json.dumps(metrics, separators=(",", ":")))
 
             return response
 
