@@ -2,7 +2,8 @@ from datetime import date
 from typing import Any, Dict, List, Optional
 
 from pydantic import BaseModel
-from typing_extensions import Literal
+
+from ..types import Literal
 
 
 class DynamoDBStreamChangedRecordModel(BaseModel):
